@@ -57,6 +57,7 @@ ALL = "*"
 DISPLAY = "display"
 IMAGE = "Image"
 LOCAL_FILESYSTEM = "Local filesystem"
+ALLOW_BROADCAST = "Allow broadcast"
 
 # Basic attributes
 ATTR_ID = "Id"
@@ -104,6 +105,7 @@ WORKER_DONE = b"2"
 MSG_EMPTY = b""
 MSG_JSON = b"J"
 MSG_ARRAY = b"A"
+MSG_BYTES = b"B"
 MSG_PICKLE = b"P"
 MSG_FILE = b"F"
 MSG_ACK = b"ACK"
@@ -500,3 +502,37 @@ ATTR_SHUTTER_STROKES = "Shutter strokes"
 ATTR_SHUTTER_OPEN = "Shutter open"
 ATTR_LAYER_THICKNESS = "Layer thickness"
 ATTR_ACTIVE_PROCESS = "Active process"
+ATTR_GROUPS = "Groups"
+ATTR_LAST_UPDATE = "Last update"
+ATTR_SOURCE_ID = "Source id"
+GROUP_FRAME = "Frame"
+ATTR_FRAME = "Frame"
+ATTR_FRAME_COUNT = "Frame count"
+ATTR_ALLOW_STREAM = "Allow stream"
+ATTR_MAX_STREAM_RATE = "Max stream rate"
+ATTR_ALLOW_BROADCAST = "Allow broadcast"
+ATTR_MAX_BROADCAST_RATE = "Max broadcast rate"
+ATTR_SOURCE = "Source"
+ATTR_SOURCE_FRAMERATE = "Source framerate"
+ATTR_SOURCE_WIDTH = "Source width"
+ATTR_SOURCE_HEIGHT = "Source height"
+ATTR_AUTO_SET_FRAMERATE = "Autoset framerate"
+ATTR_CAPTURE_API = "Capture API"
+ATTR_SOURCES_COUNT = "Sources count"
+ATTR_STREAM_READOUT = "Stream readout"
+ATTR_VALUE_READOUT = "Value readout"
+ATTR_STREAMABLE = "Streamable"
+ATTR_FULL_ACCESS = "Full access"
+ATTR_PILOT_LASER = "Pilot lasser"
+ATTR_IS_STABLE = "Is stable"
+ATTR_CAPTURE_REGION = "Capture region"
+ATTR_FourCC_CODEC = "FourCC Codec"
+ATTR_FILENAME_PREFIX = "Filename prefix"
+ATTR_RECORDING = "Recording"
+ATTR_FRAME_AGGREGATION = "Frame aggregation"
+ATTR_BUFFER_AGGREGATION = "Buffer aggregation"
+ATTR_STREAMING_MODE = "Streaming mode"
+ATTR_BUFFERS_INTERLEAVED = "Buffers interleaved"
+ATTR_FILTER_RATE = "Filter rate"
+ATTR_BUFFERS_COUNT = "Buffers count"
+ATTR_FRAMES_GRABBED = "Frames grabbed"
