@@ -28,33 +28,40 @@ class SetFunction(object):
 
 
 class Attribute(dict):
+    """
+    Class definition of Attribute.
+    """
+    # Holds main attributes, which each dict has to contain in order to be convertible into Attribute
     attribute_keys = {VALUE, TYPE, UNIT, READONLY, DESCRIPTION}
     integer_types = (int8, int16, int32, int64, uint8, uint16, uint32, uint64)
     float_types = (float16, float32, float64)
     unsigned_types = (uint8, uint16, uint32, uint64)
+    # Helper flag for SetFunction decorator
     with_set_function = False
-    last_stream_time = last_update_time = perf_counter_ns()
+    # Holds last time, that Attribute value was streamed to clients
+    last_broadcast_time = last_update_time = perf_counter_ns()
+    # Holds diff between last_stream_time and current time
     last_update_time_diff = 0
     numerical = False
+    # Token identifier associate with setting of new value
     set_token = 0
     set_callback = None
-    min_stream_timeout = 100 * 1e6
-
-    def attribute_copy(self):
-        """
-        Copy current Attribute.
-        :return: Attribute
-        """
-        return Attribute(**self)
+    # Minimum time in between of value change stream.
+    # Every Attribute change between 0 and min_broadcast_timeout will be ignored.
+    # Set this attribute to zero for Attribute that You wont to stream every change.
+    # Default value is in nanoseconds (100ms)
+    min_broadcast_timeout = 0 * 1e6
 
     def __init__(self, attribute_id=None, default_value=None, min_value=None, max_value=None, unit=None,
                  set_function=None, default_type=u"str", decimals=0, readonly=False, description=None,
-                 set_value_when_set_function=True, tolerance=(0, 0), factor=1, offset=0, save_change=False, **kwargs):
+                 set_value_when_set_function=True, tolerance=(0, 0), factor=1, offset=0, save_change=False,
+                 allow_broadcast=True, **kwargs):
         dict.__init__(self)
         self._callbacks = {}
         self.attribute_id = attribute_id
         self.set_function = set_function
         self.default_type = default_type
+
         self[OFFSET] = offset
         self[FACTOR] = factor
         # Set attribute value flag when using set function.
@@ -63,7 +70,7 @@ class Attribute(dict):
         if unit is None:
             unit = u""
         self[UNIT] = unit
-        self.min_stream_timeout = kwargs.get("min_stream_timeout", 100) * 1e6
+        self.min_broadcast_timeout = kwargs.get("min_broadcast_timeout", 0) * 1e6
         default_type = kwargs.get(TYPE, default_type)
         if default_type == TYPE_LIST:
             self[TYPE] = TYPE_LIST
@@ -96,11 +103,11 @@ class Attribute(dict):
         self[SETPOINT] = None
         self[PREVIOUS] = None
         self[SAVE_CHANGE] = save_change
+        self[ALLOW_BROADCAST] = allow_broadcast
         self.update(kwargs)
 
     def _update_set_time(self):
         """
-        Value of attribute was update.
         Set last_update_time and last_update_time_diff for future reference.
         :return: None
         """
@@ -108,8 +115,12 @@ class Attribute(dict):
         self.last_update_time_diff = update_time - self.last_update_time
         self.last_update_time = update_time
 
+    def allow_broadcast(self):
+        return self[ALLOW_BROADCAST] and (perf_counter_ns() - self.last_broadcast_time) >= self.min_broadcast_timeout
+
     def __setitem__(self, k, v):
         if k == VALUE:
+            self._update_set_time()
             try:
                 self[PREVIOUS] = self[VALUE]
             except KeyError:
@@ -151,20 +162,19 @@ class Attribute(dict):
                 self.set_token = self.set_function(setpoint)
             if not self.set_value_when_set_function:
                 return
-            self._update_set_time()
         else:
             # Store actual attribute[k] value into dictionary
             super(Attribute, self).__setitem__(k, v)
-            self._update_set_time()
 
         self.handle_callbacks(k, v)
 
     def handle_callbacks(self, k, v):
         """
         When any parameter of attribute is set, call all relevant callbacks that are attached to the parameter.
-        :param k: str
-        :param v: str
-        :return: None
+        @param k: attribute key
+        @type k: hashable
+        @param v: attribute value
+        @type v: object
         """
         # Call all relevant callbacks
         for callback, (max_update_rate, updated_at, key_filter) in self._callbacks.copy().items():
@@ -187,12 +197,22 @@ class Attribute(dict):
                 # Callback no longer exists, skipping
                 pass
 
+    def attribute_copy(self):
+        """
+        Create copy of Attribute
+        @return: Copy of this Attribute
+        @rtype: Attribute
+        """
+        return Attribute(**self)
+
     @staticmethod
     def from_dict(dictionary):
         """
-        Create Attribute from provided dictionary.
-        :param dictionary: dict
-        :return: Attribute
+        Create Attribute from dictionary.
+        @param dictionary: Dictionary
+        @type dictionary: dict
+        @return: Attribute if convertible
+        @rtype: Attribute
         """
         if isinstance(dictionary, dict):
             if Attribute.is_attribute(dictionary):
