@@ -59,9 +59,15 @@ class AttributeLogger(Device):
             try:
                 device = self.session.get_device(device_id)
                 device_attribute = device.get_attribute(attribute)
-                logged_value = device_attribute[VALUE]
-                logged_type = device_attribute[TYPE]
-                logged_unit = device_attribute[UNIT]
+
+                if device_attribute is None:
+                    logged_value = None
+                    logged_type = ""
+                    logged_unit = ""
+                else:
+                    logged_value = device_attribute[VALUE]
+                    logged_type = device_attribute[TYPE]
+                    logged_unit = device_attribute[UNIT]
                 if logged_type == "":
                     logged_type = "str"
                 if logged_unit == "":
@@ -73,6 +79,7 @@ class AttributeLogger(Device):
                 if logged_value is None:
                     logged_value = np.NaN
                 logged_values[header_lookup] = str(logged_value)
+
             except DeviceUnknownError:
                 continue
 
