@@ -60,13 +60,15 @@ class Device(Subject, YamlSerializable):
         self.connecting_time = 0
         self.response_timestamp = 0
         self.request_timestamp = 0
+        # Connection flags
         self.connected = False
         self.connecting = False
         self.closing = False
         self.closed = False
+        # Connection error flags
         self.connection_error = False
         self.response_error = False
-        self.latency_buffer = []
+        self.latency_buffer = deque(maxlen=20)
         self.init_time = time.time()
         self.commands_buffer = deque()
         Subject.__init__(self)
@@ -125,7 +127,7 @@ class Device(Subject, YamlSerializable):
 
         self.create_attribute(ATTR_ID, default_value=self.device_id, readonly=True, description="Unique device ID")
         self.create_attribute(ATTR_STATUS, default_value=STATUS_DISCONNECTED, readonly=True,
-                              description="Current device status").attach_callback(set_status)
+                              description="Current device status", min_broadcast_timeout=0).attach_callback(set_status)
         self.create_attribute(ATTR_DESCRIPTION, readonly=True, description="Device description")
         self.create_attribute(ATTR_ENABLED, default_value=True, default_type=np.bool,
                               description="Allow any external changes to device")
@@ -138,7 +140,8 @@ class Device(Subject, YamlSerializable):
         self.create_attribute(ATTR_HANGING_COMMANDS, default_value=0, default_type=np.uint32,
                               description="Amount of commands waiting to be answered from device",
                               min_value=0, readonly=True)
-        self.create_attribute(ATTR_LAST_ERROR, readonly=True, description="Last device error exception")
+        self.create_attribute(ATTR_LAST_ERROR, readonly=True, description="Last device error exception",
+                              min_broadcast_timeout=0)
 
     def create_attribute(self, name, group=None, **kwargs):
         """
@@ -437,10 +440,14 @@ class Device(Subject, YamlSerializable):
         :return: None
         """
         attribute_object = get_from_dict(self.attributes, attribute_list[:-1])
-        if attribute_list[-1] == VALUE and attribute_object.with_set_function:
-            propagate_change = attribute_object.set_value_when_set_function
+        if not attribute_object.allow_broadcast():
+            allow_broadcast = False
+        elif attribute_list[-1] == VALUE and attribute_object.with_set_function:
+            allow_broadcast = attribute_object.set_value_when_set_function
         else:
-            propagate_change = True
+            allow_broadcast = True
+        if allow_broadcast:
+            attribute_object.last_broadcast_time = time.perf_counter_ns()
 
         current_value = attribute_object[attribute_list[-1]]
         attribute_object[attribute_list[-1]] = value
@@ -449,13 +456,13 @@ class Device(Subject, YamlSerializable):
         if not set_token and callable(callback):
             callback(attribute_list, value)
 
-        if propagate_change:
+        if allow_broadcast:
             value = attribute_object[attribute_list[-1]]
             if not is_equal(current_value, value) and kamzik3.session.publisher is not None:
                 if self.session and attribute_object[SAVE_CHANGE]:
                     self.session.update_config(self.device_id, attribute_list, value)
                 header = "{}.{}".format(attribute_object.attribute_id, attribute_list[-1])
-                kamzik3.session.publisher.push_message(header, value, min_timeout=attribute_object.min_stream_timeout)
+                kamzik3.session.publisher.push_message(header, value)
 
         return set_token
 
@@ -593,10 +600,10 @@ class Device(Subject, YamlSerializable):
             (attribute, token, callback, returning), command_init_timestamp = self.commands_buffer.popleft()
             latency = (time.time() - command_init_timestamp) * 1000
             self.latency_buffer.append(latency)
-            if len(self.latency_buffer) == 20:
-                self.set_attribute((ATTR_LATENCY, VALUE), sum(self.latency_buffer) / 20.)
+            if len(self.latency_buffer) == self.latency_buffer.maxlen:
+                self.set_attribute((ATTR_LATENCY, VALUE), sum(self.latency_buffer) / self.latency_buffer.maxlen)
                 self.set_value(ATTR_HANGING_COMMANDS, len(self.commands_buffer))
-                self.latency_buffer = []
+                self.latency_buffer.clear()
         except IndexError:
             self.handle_response_error(
                 u"Trying to pop from empty command buffer. Content of readout buffer is: {}".format(readout_buffer))
