@@ -63,8 +63,8 @@ class DeviceClient(Device):
         self.set_status(STATUS_CONNECTING)
         # Get REQ type of socket
         self.socket = zmq.Context.instance().socket(zmq.REQ)
-        # Set receive timeout to 3000 ms
-        self.socket.setsockopt(zmq.RCVTIMEO, 3000)
+        # Set initial receive timeout to 20000 ms
+        self.socket.setsockopt(zmq.RCVTIMEO, 20000)
         # This is VERY IMPORTANT not to set to anything but 0
         self.monitor_socket = self.socket.get_monitor_socket()
         self.monitor_thread = Thread(target=self.connect_monitor_thread)
@@ -79,6 +79,11 @@ class DeviceClient(Device):
         self._set((ATTR_STATUS, VALUE), status)
 
     def connect_monitor_thread(self):
+        """
+        In order to monitor connect event we are using monitor socket.
+        This socket is also used to catch disconnection from server.
+        @return: None
+        """
         while not self.stopped.is_set():
             if self.monitor_socket.poll(timeout=500):
                 message = recv_monitor_message(self.monitor_socket)
@@ -218,7 +223,20 @@ class DeviceClient(Device):
             del self.callbacks[token]
 
     def handle_readout(self, token, data):
+        """
+        Handle subscribed data.
+        The most important meta is token which holds information
+        what to do with received data.
+        First check if token is within callback hooks.
+        If not then parse token an update Device's attribute.
+        @param token: "." separated mete info
+        @type token: str
+        @param data: Dict holding data items
+        @type data: dict
+        @return: None
+        """
         if token in self.callbacks:
+            # Check if there is handle hook for given token
             self.handle_readout_callback(token, data)
         else:
             attribute_parts = token.split(".")
@@ -266,7 +284,7 @@ class DeviceClient(Device):
         """
         try:
             with self.client_comm_lock:
-                self.socket.send_multipart([INSTRUCTION_INIT, self.device_id.encode()])
+                self.socket.send_multipart([INSTRUCTION_INIT, self.device_id.encode()], copy=False)
                 status, token, response = self.handle_server_response()
             if status == RESPONSE_OK:
                 allow_proxy = self.config.get("allow_proxy", True)
@@ -283,6 +301,8 @@ class DeviceClient(Device):
                     setattr(self, method_name,
                             lambda method_name=method_name, **kwargs: self.method(method_name, kwargs))
                 self._init_subscriber_thread(*device_publisher)
+                # We synced all attributes, now we want to decrease receive timeout
+                self.socket.setsockopt(zmq.RCVTIMEO, 5000)
                 return True
             else:
                 raise DeviceClientError(u"Failed to initialize device")
@@ -335,6 +355,15 @@ class DeviceClient(Device):
                 parent_attribute[key] = Attribute.from_dict(attribute)
 
     def get_token(self, topic, device_id=None):
+        """
+        Just a helper function to generate token for specific topic.
+        @param topic: topic meta
+        @type topic: str
+        @param device_id: ID of device, use this device ID if it's None
+        @type device_id: str
+        @return:
+        @rtype:
+        """
         return "{}.{}".format(self.device_id if device_id is None else device_id, topic)
 
     def set_attribute(self, attribute, value, callback=None):
@@ -347,11 +376,11 @@ class DeviceClient(Device):
         """
         if not self.connected or self.closing:
             raise DeviceClientError(
-                u"Remote set attribute {} to value {} failed. Device client is not connected".format(attribute, value))
+                f"Failed to set remote device {self.device_id} {attribute} to {value}.\r\nDevice client is not connected")
         try:
             attribute_value = json.dumps((attribute, value), ensure_ascii=True)
             with self.client_comm_lock:
-                self.socket.send_multipart([INSTRUCTION_SET, self.device_id.encode(), attribute_value.encode()])
+                self.socket.send_multipart([INSTRUCTION_SET, self.device_id.encode(), attribute_value.encode()], copy=False)
                 status, token, response = self.handle_server_response()
             if status == RESPONSE_OK:
                 if callback is not None:
@@ -361,7 +390,7 @@ class DeviceClient(Device):
                         callback(attribute, value)
             else:
                 raise DeviceClientError(
-                    u"Failed to set remote attribute {} to value {}\n{}".format(attribute, value, response))
+                    f"Failed to set remote device {self.device_id} {attribute} to {value} {self.get_attribute(attribute[:-1]).unit()}.\r\n{response}")
 
             return response
 
@@ -417,7 +446,7 @@ class DeviceClient(Device):
         try:
             with self.client_comm_lock:
                 self.socket.send_multipart(
-                    [INSTRUCTION_COMMAND, self.device_id.encode(), command.encode(), b"1" if callback else b"0"])
+                    [INSTRUCTION_COMMAND, self.device_id.encode(), command.encode(), b"1" if callback else b"0"], copy=False)
                 status, token, response = self.handle_server_response()
             if status == RESPONSE_OK:
                 if token and callback is not None:
@@ -444,7 +473,7 @@ class DeviceClient(Device):
             dumped_attributes = json.dumps(attributes, ensure_ascii=True, cls=JsonKamzikEncoder)
             with self.client_comm_lock:
                 self.socket.send_multipart(
-                    [INSTRUCTION_METHOD, self.device_id.encode(), str(method).encode(), dumped_attributes.encode()])
+                    [INSTRUCTION_METHOD, self.device_id.encode(), str(method).encode(), dumped_attributes.encode()], copy=False)
                 status, token, response = self.handle_server_response()
             if status == RESPONSE_OK:
                 return json.loads(response, object_hook=JsonKamzikHook)
@@ -477,9 +506,10 @@ class DeviceClient(Device):
         self.logger.info(u"Device configuration took {} sec.".format(time.time() - start_at))
 
     def handle_response_error(self, message=None):
-        self.logger.warning(message)
-        self.response_error = True
-        self.close()
+        if self.logger is not None:
+            self.logger.warning(message)
+            self.response_error = True
+            self.close()
 
     def handle_connection_error(self, message=None):
         self.logger.error(message)
