@@ -16,7 +16,7 @@ class DeviceFileSync(Device):
     def _init_attributes(self):
         super(DeviceFileSync, self)._init_attributes()
         self.create_attribute(ATTR_FILEPATH, set_function=self.set_filepath, readonly=True)
-        self.create_attribute(ATTR_CONTENT, set_function=self.set_content)
+        self.create_attribute(ATTR_CONTENT, set_function=self.set_content, display=False, allow_stream=False)
 
     def handle_configuration(self):
 
