@@ -52,7 +52,10 @@ class DevicePort(Device):
 
     def read_all(self):
         if self.serial_port.in_waiting > 0:
-            return self.serial_port.read(self.serial_port.in_waiting).decode("utf-8")
+            if self.command_encoding is not None:
+                return self.serial_port.read(self.serial_port.in_waiting).decode(self.command_encoding)
+            else:
+                return self.serial_port.read(self.serial_port.in_waiting)
         else:
             return None
 
