@@ -24,6 +24,6 @@ class DevicePublisher(Publisher, Thread):
                      message], copy=False)
             else:
                 json_message = json.dumps(message, cls=JsonKamzikEncoder, ensure_ascii=True)
-                self.socket_publisher.send_multipart([header.encode(), MSG_JSON, json_message.encode()])
+                self.socket_publisher.send_multipart([header.encode(), MSG_JSON, json_message.encode()], copy=False)
         except Exception as e:
             self.logger.error("{}, {}, {}".format(e, header, message))
