@@ -382,6 +382,10 @@ class DeviceSession(Device):
         :return: None
         """
         self.stop_polling()
+        if self.get_value(ATTR_ALLOW_ATTRIBUTE_LOG):
+            logger = self.get_device("AttributeLogger")
+            if logger is not None:
+                logger.stop()
 
         if self.server is not None:
             self.server.stop()
