@@ -575,5 +575,5 @@ class DeviceMCS2FlyScanner(DeviceScanner):
         raise NotImplementedError
 
     @expose_method()
-    def get_scanner_macro(self, scanner_input, scanner_attributes):
+    def get_scanner_macro(self, scanner_input, scanner_attributes, parent_macro=None):
         raise NotImplementedError
