@@ -66,7 +66,7 @@ class DeviceWidget(Observer, QWidget, YamlSerializable):
 
     @pyqtSlot("PyQt_PyObject", "PyQt_PyObject")
     def slot_check_error(self, attribute, output):
-        if attribute == RESPONSE_ERROR.decode():
+        if attribute == RESPONSE_ERROR:
             self.logger.error(output)
             show_error_message(output, parent=self)
 
@@ -87,7 +87,7 @@ class DeviceWidget(Observer, QWidget, YamlSerializable):
     def slot_set_status(self, value):
         """
         This slot is always called when device status has changed.
-        Recall thic method when overloading.
+        Recall this method when overloading.
         :param value:
         :return:
         """
