@@ -2,6 +2,7 @@ import numpy as np
 from PyQt5.QtCore import pyqtSlot
 from PyQt5.QtWidgets import QWidget
 
+import kamzik3
 from kamzik3 import units
 from kamzik3.constants import *
 from kamzik3.devices.attribute import Attribute
@@ -285,6 +286,17 @@ class MacroWidget(QWidget, YamlSerializable):
         self.macro_inputs["on_warning"] = on_warning_widget
         return on_warning_widget
 
+    def _get_scanner(self):
+        scanner = self.config.get("scanner", "None")
+        if scanner == "None":
+            scanner = None
+        scanner_attributes = {}
+        if scanner is not None:
+            scanner_device = kamzik3.session.get_device(scanner)
+            for attribute in scanner_device.get_scanner_attributes():
+                scanner_attributes[attribute] = self.macro_inputs[attribute].get_attribute_value()
+        return scanner, scanner_attributes
+
     def get_input_values(self):
         output = {}
         for key, input in self.macro_inputs.items():
