@@ -122,7 +122,7 @@ class MacroStepWidget(Ui_Form, MacroWidget):
 
     def _init_scanner_list(self):
         self.combobox_scanner.blockSignals(True)
-        devices_list = list(kamzik3.session.get_devices(method_filter="get_scanner_macro").keys())
+        devices_list = list(kamzik3.session.get_devices(method_filter="get_scanner_attributes").keys())
 
         self.combobox_scanner.addItems(["None"] + devices_list)
         self.combobox_scanner.blockSignals(False)
@@ -321,6 +321,7 @@ class MacroStepWidget(Ui_Form, MacroWidget):
         try:
             values = self.get_input_values()
             step = None
+            scanner, scanner_attributes = self._get_scanner()
             if self.config.get("attribute") is not None:
                 if self.attribute.numerical:
                     step = StepDeviceAttributeNumerical(
@@ -342,7 +343,8 @@ class MacroStepWidget(Ui_Form, MacroWidget):
                         on_warning=self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else
                         values["on_warning"],
                         timeout=units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values[
-                            "timeout"]).to("s")
+                            "timeout"]).to("s"),
+                        scanner=scanner, scanner_attributes=scanner_attributes
                     )
                 else:
                     step = StepDeviceAttribute(
@@ -360,7 +362,8 @@ class MacroStepWidget(Ui_Form, MacroWidget):
                         on_warning=self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else
                         values["on_warning"],
                         timeout=units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values[
-                            "timeout"]).to("s")
+                            "timeout"]).to("s"),
+                        scanner=scanner, scanner_attributes=scanner_attributes
                     )
             elif self.config.get("method") is not None:
                 method_parameters = {}
@@ -386,14 +389,9 @@ class MacroStepWidget(Ui_Form, MacroWidget):
                     on_warning=self.config.get("on_warning", "Abort macro") if self.user_mode == MODE_SIMPLE else
                     values["on_warning"],
                     timeout=units.Quantity(self.config.get("timeout", "0s") if self.user_mode == MODE_SIMPLE else values[
-                        "timeout"]).to("s")
+                        "timeout"]).to("s"),
+                    scanner=scanner, scanner_attributes=scanner_attributes
                 )
-            if self.config.get("scanner", "None") != "None":
-                scanner = kamzik3.session.get_device(self.config["scanner"])
-                scanner_attributes = {}
-                for attribute in scanner.get_scanner_attributes():
-                    scanner_attributes[attribute] = self.macro_inputs[attribute].get_attribute_value()
-                step = scanner.get_scanner_macro(scanner_input=step, scanner_attributes=scanner_attributes)
             return step
         except KeyError:
             raise KeyError("One of attributes for {} were not set".format(self.title))
