@@ -116,6 +116,16 @@ class MacroServer(Device):
     def get_uploaded_macros(self):
         return list(self.uploaded_macros.keys())
 
+    @expose_method()
+    def get_running_macros_meta(self):
+        macros_meta_list = []
+        for running_macro in self.running_macros.values():
+            macros_meta_list.append({
+                "id": running_macro.device_id,
+                "header": running_macro.macro_logger.get_value(ATTR_HEADER)
+            })
+        return macros_meta_list
+
     @expose_method({"macro_id": "ID of uploaded macro"})
     def get_macro_template(self, macro_id):
         try:
