@@ -1,5 +1,6 @@
 import json
 import time
+from base64 import b64encode, b64decode
 
 import numpy as np
 
@@ -15,6 +16,8 @@ class JsonKamzikEncoder(json.JSONEncoder):
             return {"pint-unit-quantity": o.to_tuple()}
         elif isinstance(o, np.ndarray):
             return {"numpy-array": o.tolist(), "dtype": o.dtype.name, "shape": o.shape}
+        elif isinstance(o, bytes):
+            return {"bytes": b64encode(o).decode()}
         elif isinstance(o, Device):
             return {"kamzik3-device": o.device_id}
         return json.JSONEncoder.default(self, o)
@@ -24,9 +27,9 @@ def JsonKamzikHook(dct):
     if 'pint-unit-quantity' in dct:
         return units.Quantity.from_tuple(dct['pint-unit-quantity'])
     elif "numpy-array" in dct:
-        a = time.perf_counter_ns()
-        np_array = np.asarray(dct.get("numpy-array"), dtype=dct.get("dtype"))
-        return np_array
+        return np.asarray(dct.get("numpy-array"), dtype=dct.get("dtype"))
+    elif "bytes" in dct:
+        return b64decode(dct.get("bytes"))
     elif "kamzik3-device" in dct:
         return kamzik3.session.get_device(dct.get("kamzik3-device"))
     return dct
